@@ -27,18 +27,12 @@ calc_duration <- function(start = NA, end = NA, units = 'years') {
 
   # Hard Stops
   if (
-    !(
-      all(lubridate::is.Date(start), na.rm = TRUE) |
-      all(lubridate::is.POSIXt(start), na.rm = TRUE) |
-      all(is.na(start))
-    ) &
-    !(
-      all(lubridate::is.Date(end), na.rm = TRUE) |
-      all(lubridate::is.POSIXt(end), na.rm = TRUE) |
-      all(is.na(end))
-    )
+    !(all(lubridate::is.Date(start), na.rm = TRUE) | all(lubridate::is.POSIXt(start), na.rm = TRUE)) |
+    !(all(lubridate::is.Date(end), na.rm = TRUE) | all(lubridate::is.POSIXt(end), na.rm = TRUE)) |
+    all(is.na(start)) |
+    all(is.na(end))
   ) stop('Missing Date or POSIXt object. Check: [\'start\', \'end\']')
-  if (length(start) != length(end) & all(length(start) > 1, length(end) > 1))
+  if (length(start) != length(end) & length(start) > 1 & length(end) > 1)
     stop('Provided data are not of the same length. Check [\'start\', \'end\']')
 
   # Handle multiple calculations off single timepoint
@@ -54,3 +48,39 @@ calc_duration <- function(start = NA, end = NA, units = 'years') {
   # Calculate and return data
   as.numeric(lubridate::as.duration(lubridate::interval(start, end)), units)
 }
+
+#' @title Calculate indices of data "chunks" in a data object
+#' @description Calculates chunk indices of a data object
+#' for a given chunk size (number of items per chunk).
+#' @param data Required. Tibble, data frame, vector.
+#' @param size Optional. Integer. The number of items (e.g. rows in a tibble)
+#' that make up a given chunk. Must be a positive integer. Defaults to 10 or max.
+#' @param reverse Optional. Logical. Calculate chunks from back to front.
+#' Defaults to front to back order.
+#' @return An iterable list of row indices for each chunk of data.
+#' @examples
+#' # Create chunk map for a data frame
+#' chunks <- calc_chunks(mtcars, size = 6)
+#'
+#' # Iterate through chunks of data
+#' for (chunk in chunks) print(paste0(rownames(mtcars[chunk,]), collapse = ', '))
+#' @export
+calc_chunks <- function(data = NULL, size = 10, reverse = FALSE) {
+
+  # Hard stops
+  if (is.null(data) | (!tibble::is_tibble(data) & !is.data.frame(data) & !is.vector(data)))
+    stop('Invalid data type provided. [check: \'data\']')
+  if (!is.numeric(size) | size < 1)
+    stop('Invalid data type provided. [check: \'size\']')
+
+  # Variables
+  item_cnt <-
+    if (tibble::is_tibble(data) | is.data.frame(data)) nrow(data)
+  else length(data)
+  if (size > item_cnt) size <- item_cnt
+
+  # Calculate and return chunks
+  if (!reverse) purrr::map(1:ceiling(item_cnt / size), ~ ((.x-1)*size+1):min(item_cnt, (.x*size)))
+  else purrr::map(1:ceiling(item_cnt / size), ~ (item_cnt-(.x-1)*size):max(1, item_cnt-(.x*size)+1))
+
+}
